using DelimitedFiles

OVERWRITE = false

gamma        = [0.44 0.55 0.66 0.77 0.88]
sigma        = [1 2 4 8 16 32 64]
rnaught      = range(1, length=40, stop=5)
mu           = range(0.01, length=40, stop=0.25)

#gamma        = collect(range(0.01, 0.99, length=25))
#sigma        = 10.0 .^ range(-0.83, 3.15, length=25)
#rnaught      = [4] #collect(range(1, 8, length=10))
#mu           = [0.02] #collect(range(0.01, 0.2, length=10))


# params = [[γ1 γ2 σ1 σ2 R0] for γ1 in gamma for σ1 in sigma for γ2 in gamma for σ2 in sigma for R0 in rnaught]
params = [[γ σ R0 μ] for γ in gamma for σ in sigma for R0 in rnaught for μ in mu]

writedlm("state_space_param_list.csv", vcat(params...))

file_base = "SSE1p_"

n_jobs = 250
job_length = ceil(length(params) / n_jobs)
modulo_job_length = (1:length(params)) .% job_length

indices = zip(findall(modulo_job_length .== 1), findall(modulo_job_length .== 0))

for (start_index, stop_index) in indices
    # if isfile("../Results/SSE/[2 2];[-0.05 0.05; 0.0 0.0];10000.0;$start_index;$stop_index;0.02.csv") & !OVERWRITE
    if isfile("../Results/SSE1p/[2 2];10000.0;$start_index;$stop_index.csv") & !OVERWRITE
        continue
    end
    open("$file_base$start_index-$stop_index.jl", "w") do f
        write(f, """
        using DelimitedFiles
        include("state_space_exploration.jl")
        all_params = readdlm("state_space_param_list.csv")
        # explore_parameter_space([all_params[x,:] for x in $start_index:$stop_index], $start_index, $stop_index)
        explore_parameter_space_one_pop([all_params[x,:] for x in $start_index:$stop_index], $start_index, $stop_index)
        """)
    end

    open("$file_base$start_index-$stop_index.sh", "w") do f
        write(f, """
        #!/bin/bash
        #PBS -N $file_base$start_index-$stop_index.sh
        #PBS -j oe
        #PBS -l walltime=04:00:00
        #PBS -l nodes=1:ppn=8
        #PBS -l pmem=8gb

        cd ~/multipop_mantis/Code/
        ~/julia/julia $file_base$start_index-$stop_index.jl
        """)
    end
    run(`qsub $file_base$start_index-$stop_index.sh`)
    sleep(0.1)
end
