% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MANTIS.R
\name{extractNoveltyVariant}
\alias{extractNoveltyVariant}
\title{Extract antigenic novelty dynamics.}
\usage{
extractNoveltyVariant(data, extThreshold)
}
\arguments{
\item{data}{the list as obtained from running the simulation. See \code{?runMANTIS} for details.}

\item{extThreshold}{theoretical extinction threshold for the pathogen. Since MANTIS is based on deterministic and
continuous numerical simulations, strains are always present in the population (their prevalences are always
bigger than zero). This is particularly important for the concept of antigenic novelty - by necessarily having
to initialize all strains at prevalences bigger than zero, novelty is readily 100 percent at the initial time
step. For this reason, the consideration of an extinction threshold was added. This allows the user to consider
theoretical (host) population sizes, assuming that prevalences under the threshold should equate to the virtual
extinction of pathogen strains. Variants therefore emerge (appear for the first time) as novel types only when
they breach the threshold.}
}
\value{
a list with two data.frames. The first data.frame contains the time series in which the first column is
time and second column is the number of the variant (strain) that has emerged for the first time above the
theoretical extinction threshold (\code{extThreshold}). The second data.frame contains the time series in which
the first column is time and the second column is the percent of the antigenic space that has been explored by
novelty.
}
\description{
Extracts time series containing the solution for antigenic dynamics based on novelty. Novelty is defined
as the first appearance of variants (strains) in the population. This crucially depends on the assumption
of the theoretical host population size. See the definition of \code{extThreshold} below for details.
}

