% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MANTIS.R
\name{runMANTIS}
\alias{runMANTIS}
\title{Run the Multilocus ANTIgenic Simulator (MANTIS)}
\usage{
runMANTIS(epiStruc, tMax, tObsPer, tStep, initCondY, beta, gamma, sigma, mu,
  epsilon = 0, initCondZ = NA, initCondW = NA)
}
\arguments{
\item{epiStruc}{desired antigenic structure for the simulation. It should be an array of integers specifying the number of alleles per locus. Its length determines the number of loci and each integer the number of alleles per locus. The minimum number of loci allowed is 2 (\code{length(epiStruc)>=2}) and therefore the minimum number of strains in the system is also 2. If the user wants to simulate 2 strains, the second locus can be set to have only one allele, that is \code{epiStruct=c(2,1)}.}

\item{tMax}{the time at which the solver will stop solving the ODE system.}

\item{tObsPer}{an integer specifying the periodicity at which the solution is recorded. It may be used to reduce the size of the output variable considerably.}

\item{tStep}{time step for the fixed-step ODE solver. If the dynamics of the system appear inconsistent, this should be reduced.}

\item{initCondY}{initial conditions for the infectious classes (\code{Yi}). This is a collection of numbers of length equal to the number of strains in the system. Its sum needs to be smaller than 1, as initial conditions represent proportions.}

\item{beta}{numeric value or collection of numbers. If a single value is given, all strains will share beta=value. If a collection of numbers is given, it is required that the length of the collection be equal to the number of strains; in this case each strain indexes the collection and can have a different value for beta.}

\item{gamma}{number representing cross-protection given by challenge of strains that share alleles. This needs to be between 0 and 1 (inclusive), for which 0 confers no protection and 1 full protection.}

\item{sigma}{number representing the recovery rate (also known as the loss of infection rate). \code{1/sigma} is the infectious period.}

\item{mu}{number representing the death rate of all individuals in the system. \code{1/mu} is the mean life-span.}

\item{epsilon}{number representing the strength of seasonality changes in \code{beta}, defaults to zero. \code{epsilon=0} equates to 
no seasonality changes. If \code{epsilon>0}, \code{beta} suffers from yearly seasonal changes. Seasonality is modelled via 
a sinusoidal signal, defined as \code{beta*(1.0+epsilon*pow(sin(PI*t),6))}. This means that \code{beta} is the minimum (out of season)
and \code{beta*(1+epsilon)} the peak of the season. NOTE: seasonality expects model parameters to be defined per year, as modelled
oscillations are per year. Seasonality parameters can be tested using the function \code{testSeasonality}, see ?testSeasonality.}

\item{initCondZ}{initial conditions for the infectious classes (\code{Zi}). This is a collection of numbers of length equal to the number of strains in the system. Its sum needs to be smaller than 1, as initial conditions represent proportions. This is optional and will be assumed zero if not given.}

\item{initCondW}{initial conditions for the infectious classes (\code{Wi}). This is a collection of numbers of length equal to the number of strains in the system. Its sum needs to be smaller than 1, as initial conditions represent proportions. This is optional and will be assumed zero if not given.}
}
\value{
A 'list' of size 4.  The first element is 'time'; the second element is the resulting 'time series'; the third element 
contains the information about 'shared epitopes' between strains; and the fourth element contains the 'allelic matrix' which describes
the allelic combination that defines each strain in the system.

'time' is an array of numbers representing the time steps of the simulation's solution, its length is determined by \code{tMax/tStep}. 

'time series' is a matrix with \code{tMax/tStep} rows and \code{3*nStrains} columns (nStrains is the number of strains). Each column of 'time series'
represents an epidemiological class (equation) in the system. Columns \code{1}:\code{nStrains} are the classes \code{Zi} for each \code{strain i},  
representing individuals with specific-immunity to \code{strain i}. Columns \code{(nStrains+1)}:\code{(nStrains*2)} are the classes \code{Wi}
for each \code{strain i}, representing cross-reactive individuals to \code{strain i}. Columns \code{(nStrains*2+1):(nStrains*3)} are 
the classes \code{Yi} for each \code{strain i}, representing infectious individuals with \code{strain i}. For more details on the epidemiological
framework, including variables \code{Z, W, Y} and biological parameters, see references in the output of function \code{readingMANTIS() }.

'shared epitopes' is a matrix with N rows and M columns. N equals the number of strains and M the number of possible strains to which each strain
can share an allele. Each row \code{i} contains a set of integer numbers identifying which other strains share an allele with strain \code{i}.
For example, for an antigenic structure \code{epiStruct=c(2,2)}, giving 4 strains, 'shared epitopes' will have 4 rows in which the first will contain 
\code{"1 2 3"}, meaning that strain 1 shares alleles with strain 1, 2 and 3.

'allelic matrix' is a matrix with N rows and L columns. N equals the number of strains and L the number of loci. For simplification, alleles
are defined by integer numbers from \code{1....Al}, with \code{Al} being the maximum diversity allowed at each loci \code{l}. Each row represents
the combination of alleles that define each strain.
}
\description{
Function that runs the multilocus model. A deterministic ordinary-differential equations system (ODE) is solved. For more
details on the conceptual framework, including variables and biological parameters, a summary can be found in the 
manual. References to the literature can also be found by running the function \code{readingMANTIS()}.
}

