library(tidyverse)
library(magrittr)
library(janitor)

my_cols <- c("#f74700", "#016394", "#b6003b", "#005342")

get_dynamics <- ~case_when(. == -1 ~ "extinct",
                           . == 0 ~ "steady",
                           . == 1 ~ "unconverged",
                           . > 1  ~ "cycles")

all_results <- list.files("../../Results/SSE1p_gamma,sigma/", full.names=TRUE) %>%
  lapply(read_csv,
         col_names=c("strain", "n_extrema_noround", "n_extrema_round12", "n_extrema_round10", "n_extrema_round8", "gamma", "sigma", "R0", "mu"),
         col_types="ddddddddd") %>%
  bind_rows() %>%
  group_by(strain, gamma, sigma, R0, mu) %>%
  mutate(rep = 1:n()) %>%
  ungroup() %>%
  mutate_at(vars(starts_with("n_extrema")), get_dynamics) %>%
  group_by(rep, gamma, sigma, mu, R0) %>%
  summarise_at(vars(starts_with("n_extrema")),
               . %>% sort() %>% table() %>% {str_c(., names(.), collapse="")}) %>%
  group_by(gamma, sigma, mu, R0) %>%
  summarise_at(vars(starts_with("n_extrema")),
               . %>% sort(decreasing=TRUE) %>% head(-2) %>% tail(-2) %>%
               {ifelse(length(unique(.)) == 1, .[1],
                       .[str_detect(., "unconverged", negate=TRUE)] %>%
                         table() %>%
                         {str_c(., names(.), sep=":", collapse="_")})}) %>%
  mutate_at(vars(starts_with("n_extrema")), ~case_when(. == "4steady" ~ "steady",
                                                       . == "4cycles" ~ "cycles",
                                                       str_detect(., "unconverged") ~ "unconverged",
                                                       . == "2extinct2steady" ~ "extinct",
                                                       TRUE ~ "unconverged"))

ggplot(all_results %>% ungroup() %>%
         select(gamma, sigma, mu, R0, dynamics=n_extrema_round8) %>%
         complete(sigma, gamma, mu, R0, fill=list("dynamics"="unconverged"))) +
  aes(x=gamma, y=sigma, fill=dynamics) +
  xlab(expression(gamma)) + ylab(expression(sigma)) +
  geom_raster(alpha=0.7) +
  scale_y_log10() +
  scale_x_continuous(breaks=0:4 / 4, labels=c("0", "0.25", "0.5", "0.75", "1")) +
  coord_cartesian(expand=FALSE) +
  scale_fill_manual(values=my_cols) +
  facet_grid(str_glue("{expression(R[0])}=={round(R0, 3)}") ~
               str_glue("{expression(mu)}=={round(mu, 3)}"),
             labeller=label_parsed) +
  theme_bw() +
  theme(panel.grid=element_blank())
ggsave("state_space_[2,2]_gammaxsigma.png", width=10, height=10)
