library(magrittr)
library(tidyverse)
library(JuliaCall)

julia_setup()
julia_source("state_space_exploration.jl")

chi       <- 0.05 #matrix(c(-0.05, 0, 0.05, 0), 2, 2)
structure <- c(2, 2)
maxtime   <- 10000
gamma     <- seq(0.01, 0.99, length.out=2)
mu        <- 0.02
sigma     <- mu * 10^seq(1, 3.5, length.out=1)
R0        <- c(2, 4, 8)

mantis_output <- julia_call("explore_parameter_space", strainstruct=structure,
                            chi=chi, maxtime=maxtime, gamma=gamma, sigma=sigma, mu=mu, rnaught=R0)

clean_output <- . %>%
  as.data.frame() %>%
  mutate_all(unlist) %>%
  as_tibble() %>%
  rename(strain=V1, n_extrema=V2, gamma=V3, sigma=V4, R0=V5, mu=V6) %>%
  mutate(dynamics = case_when(n_extrema == 0 ~ "extinct",
                              n_extrema == 1 ~ "steady",
                              n_extrema > 1 ~ "cycles")) %>%
  group_by(gamma, sigma, R0, mu) %>%
  summarise(dynamics = dynamics %>% sort() %>% table() %>% {str_c(., names(.), collapse="")})

plot_data <- clean_output(mantis_output)

ggplot(plot_data) +
  aes(x=gamma, y=sigma, fill=dynamics) +
  geom_raster() +
  scale_y_log10() +
  scale_fill_viridis_d(option="C") +
  coord_cartesian(expand=FALSE) +
  facet_grid(mu~R0)